SpringAnimation

Struct SpringAnimation 

pub struct SpringAnimation {
    pub value: f32,
    pub velocity: f32,
    pub target: f32,
    pub stiffness: f32,
    pub damping: f32,
}
Spring-based animation for smooth, physics-based motion

This uses a damped spring physics model for natural-looking animations. Unlike timed animations, springs don’t have a fixed duration - they settle over time.

Example

use armas_basic::animation::SpringAnimation;

let mut spring = SpringAnimation::new(0.0, 1.0)
    .params(200.0, 20.0);
spring.update(0.016); // one frame at 60fps
let current = spring.value;

Fields

value: f32

Current value

velocity: f32

Current velocity

target: f32

Target value

stiffness: f32

Spring stiffness (higher = faster oscillation, typical: 100-300)

damping: f32

Spring damping (higher = less oscillation, typical: 10-30)

Implementations

Source

impl SpringAnimation

pub const fn new(initial: f32, target: f32) -> Self

Create a new spring animation

pub const fn params(self, stiffness: f32, damping: f32) -> Self

Set spring parameters

pub fn update(&mut self, dt: f32)

Update the spring simulation using semi-implicit Euler integration

pub const fn set_target(&mut self, target: f32)

Set a new target value

pub fn is_settled( &self, position_threshold: f32, velocity_threshold: f32, ) -> bool

Check if the spring has approximately settled at the target

pub const fn reset(&mut self, value: f32, target: f32)

Reset the spring to a new position with zero velocity