Input Group Component (shadcn/ui style)
A container that wraps a text input with leading/trailing addon slots for icons, text labels, or buttons.
use armas_basic::prelude::*;
let mut text = String::new();
InputGroup::new("search_input")
.leading(|ui| { ui.label("๐"); })
.show(ui, &mut text);Structs
- Input
Group - Input group โ a text input with leading/trailing addons.
- Input
Group Response - Response from an input group.