Skeleton

Struct Skeleton 

pub struct Skeleton {
    pub width: f32,
    pub height: f32,
    pub speed: f32,
    pub shimmer_width: f32,
    /* private fields */
}
Skeleton loader for placeholder content

A shimmer effect that animates across a rectangular area, useful for indicating loading content.

Example

use armas_basic::components::Skeleton;

fn ui(ui: &mut egui::Ui, skeleton: &mut Skeleton) {
    skeleton.show(ui);
}

Fields

width: f32

Width of the skeleton

height: f32

Height of the skeleton

speed: f32

Animation speed

shimmer_width: f32

Width of the shimmer effect

Implementations

Source

impl Skeleton

pub const fn new(width: f32, height: f32) -> Self

Create a new skeleton loader Colors default to theme surface_variant and surface

pub const fn base_color(self, color: Color32) -> Self

Set the base color (overrides theme)

pub const fn highlight_color(self, color: Color32) -> Self

Set the highlight color (overrides theme)

pub const fn speed(self, speed: f32) -> Self

Set the animation speed

pub const fn corner_radius(self, radius: f32) -> Self

Set the corner radius (overrides theme)

pub const fn shimmer_width(self, width: f32) -> Self

Set the shimmer width (as a fraction of total width)

pub fn show(&mut self, ui: &mut Ui) -> Response

Show the skeleton loader