Pagination

Struct Pagination 

pub struct Pagination { /* private fields */ }
Pagination component for navigating through pages

Styled like shadcn/ui Pagination with previous/next buttons and page numbers.

Example

use armas_basic::Pagination;

let resp = Pagination::new(1, 10).show(ui);
// current_page is the current page after any user interaction

Implementations

Source

impl Pagination

pub fn new(initial_page: usize, total_pages: usize) -> Self

Create a new pagination component

Arguments
  • initial_page - Initial/current page (1-indexed)
  • total_pages - Total number of pages
pub fn id(self, id: impl Into<Id>) -> Self

Set ID for state persistence

pub const fn sibling_count(self, count: usize) -> Self

Set the number of sibling pages to show on each side of current page

pub const fn show_prev_next(self, show: bool) -> Self

Show or hide previous/next buttons

pub const fn button_size(self, button_size: f32) -> Self

Set the size of page number and ellipsis buttons

pub fn show(self, ui: &mut Ui) -> PaginationResponse

Show the pagination and return PaginationResponse