Module icon

Module icon 

Icon rendering Icon system for Armas

Re-exports the generic icon infrastructure from armas_icon and provides procedural drawing functions for the small set of icons used by built-in components (close, chevrons, info, error).

For custom icons, use armas_icon::Icon with your own armas_icon::IconData or parse SVGs at runtime with the runtime feature of armas_icon.

Structs

Icon
Generic icon widget
IconData
Pre-tessellated icon data
OwnedIconData
Icon data that owns its buffers.

Functions

draw_chevron_down
Draw a chevron-down icon (v) within the given rect.
draw_chevron_left
Draw a chevron-left icon (<) within the given rect.
draw_chevron_right
Draw a chevron-right icon (>) within the given rect.
draw_close
Draw a close icon (X) within the given rect.
draw_error
Draw an error icon (circle with “!”) within the given rect.
draw_info
Draw an info icon (circle with “i”) within the given rect.
render_icon
Render icon data to an egui painter.
render_icon_data
Render icon geometry to an egui painter.