ResizablePanel

Struct ResizablePanel 

pub struct ResizablePanel {
    pub default_size: f32,
    pub min_size: Option<f32>,
    pub max_size: Option<f32>,
}
Configuration for a single panel in a resizable group.

Fields

default_size: f32

Default size as a fraction (0.0..1.0).

min_size: Option<f32>

Minimum size fraction.

max_size: Option<f32>

Maximum size fraction.

Implementations

Source

impl ResizablePanel

pub const fn new(default_size: f32) -> Self

Create a new panel with a default size fraction.

pub const fn min_size(self, min: f32) -> Self

Set the minimum size fraction.

pub const fn max_size(self, max: f32) -> Self

Set the maximum size fraction.