Interpolation trait for animating values Interpolation trait and helpers for animating values.
Implemented for f32, f64, Color32, Pos2, Vec2, and Rect.
Traits
- Interpolate
- Trait for types that can be interpolated between two values
Functions
- lerp
- Helper function for smooth interpolation with custom easing
- smooth_
step - Smooth step interpolation (S-curve)
- smoother_
step - Smoother step interpolation (smoother S-curve)