pub struct SpringAnimation {
pub value: f32,
pub velocity: f32,
pub target: f32,
pub stiffness: f32,
pub damping: f32,
}Expand description
Spring-based animation for smooth, physics-based motion
This uses a damped spring physics model for natural-looking animations. Unlike timed animations, springs don’t have a fixed duration - they settle over time.
Example
use armas_basic::animation::SpringAnimation;
let mut spring = SpringAnimation::new(0.0, 1.0)
.params(200.0, 20.0);
spring.update(0.016); // one frame at 60fps
let current = spring.value;Fields
value: f32Current value
velocity: f32Current velocity
target: f32Target value
stiffness: f32Spring stiffness (higher = faster oscillation, typical: 100-300)
damping: f32Spring damping (higher = less oscillation, typical: 10-30)
Implementations
Sourceimpl SpringAnimation
impl SpringAnimation
Sourcepub fn update(&mut self, dt: f32)
pub fn update(&mut self, dt: f32)
Update the spring simulation using semi-implicit Euler integration
Sourcepub const fn set_target(&mut self, target: f32)
pub const fn set_target(&mut self, target: f32)
Set a new target value
Sourcepub fn is_settled(
&self,
position_threshold: f32,
velocity_threshold: f32,
) -> bool
pub fn is_settled( &self, position_threshold: f32, velocity_threshold: f32, ) -> bool
Check if the spring has approximately settled at the target