pub struct HoverCard { /* private fields */ }Expand description
Hover Card — appears on hover over a trigger element.
Example
use armas_basic::components::HoverCard;
let mut card = HoverCard::new("user_card");
card.show(ctx, trigger, |ui| {
ui.label("User details here");
});Implementations
Sourceimpl HoverCard
impl HoverCard
Sourcepub const fn open_delay(self, delay: f32) -> Self
pub const fn open_delay(self, delay: f32) -> Self
Set the delay before the card opens on hover (seconds).
Sourcepub const fn close_delay(self, delay: f32) -> Self
pub const fn close_delay(self, delay: f32) -> Self
Set the delay before the card closes after hover leaves (seconds).
Sourcepub const fn position(self, pos: PopoverPosition) -> Self
pub const fn position(self, pos: PopoverPosition) -> Self
Set the card position relative to the trigger.