Context extension for Armas theme storage
This extension trait allows storing the Armas theme in egui’s context, eliminating the need to pass theme to every component.
Traits
- Armas
Context Ext - Extension trait for storing Armas theme in egui Context